==> jc-1.4.0.tar.gz: ppg/cmds/OverrideCmd.h <==
// public class ppg.cmds.OverrideCmd

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9ca1523966fe1d6c ppg_cmds_OverrideCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_OverrideCmd_H_
#define _JC_ppg_cmds_OverrideCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_ppg_atoms_Nonterminal$object;
struct _jc_ppg_atoms_Production$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_OverrideCmd$sub_refs	_jc_ppg_cmds_OverrideCmd$sub_refs;
typedef struct _jc_ppg_cmds_OverrideCmd$sub_nonrefs	_jc_ppg_cmds_OverrideCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_OverrideCmd$refs	_jc_ppg_cmds_OverrideCmd$refs;
typedef struct _jc_ppg_cmds_OverrideCmd$nonrefs	_jc_ppg_cmds_OverrideCmd$nonrefs;
typedef struct _jc_ppg_cmds_OverrideCmd$object	_jc_ppg_cmds_OverrideCmd$object;

typedef const struct _jc_ppg_cmds_OverrideCmd$vmethods	_jc_ppg_cmds_OverrideCmd$vmethods;
typedef const struct _jc_ppg_cmds_OverrideCmd$vtable	_jc_ppg_cmds_OverrideCmd$vtable;
typedef const struct _jc_ppg_cmds_OverrideCmd$vtype	_jc_ppg_cmds_OverrideCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_OverrideCmd$method$_init$366f936045042a22(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *, struct _jc_ppg_atoms_Production$object *);

// Virtual methods
extern struct _jc_ppg_atoms_Nonterminal$object *_jc_ppg_cmds_OverrideCmd$method$getLHS$7fbea68fdd3a7c01(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *);
extern struct _jc_ppg_atoms_Production$object *_jc_ppg_cmds_OverrideCmd$method$getProduction$794612980e712f24(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *);
extern void _jc_ppg_cmds_OverrideCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_OverrideCmd$method_info$getLHS$7fbea68fdd3a7c01;
extern _jc_method _jc_ppg_cmds_OverrideCmd$method_info$getProduction$794612980e712f24;
extern _jc_method _jc_ppg_cmds_OverrideCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_OverrideCmd$vmethods {
	struct _jc_ppg_atoms_Nonterminal$object	*(*getLHS$7fbea68fdd3a7c01)(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *);
	struct _jc_ppg_atoms_Production$object	*(*getProduction$794612980e712f24)(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_cmds_OverrideCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_OverrideCmd$vmethods	ppg_cmds_OverrideCmd;
};

// Vtype
struct _jc_ppg_cmds_OverrideCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_OverrideCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_OverrideCmd$sub_refs {
	struct _jc_ppg_atoms_Production$object	*prod;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_OverrideCmd$refs {
    _jc_ppg_cmds_OverrideCmd$sub_refs	ppg_cmds_OverrideCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_OverrideCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_OverrideCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_OverrideCmd$sub_nonrefs	ppg_cmds_OverrideCmd;
};

// Object instance structure
struct _jc_ppg_cmds_OverrideCmd$object {
	_jc_ppg_cmds_OverrideCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_OverrideCmd$vtype	*vtype;
	_jc_ppg_cmds_OverrideCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_OverrideCmd$vtype _jc_ppg_cmds_OverrideCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_OverrideCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_OverrideCmd$class_object;

#endif	/* _JC_ppg_cmds_OverrideCmd_H_ */

==> jc-1.4.6.tar.gz: ppg/cmds/OverrideCmd.h <==
// public class ppg.cmds.OverrideCmd

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9ca1523966fe1d6c ppg_cmds_OverrideCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_OverrideCmd_H_
#define _JC_ppg_cmds_OverrideCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_ppg_atoms_Nonterminal$object;
struct _jc_ppg_atoms_Production$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_OverrideCmd$sub_refs	_jc_ppg_cmds_OverrideCmd$sub_refs;
typedef struct _jc_ppg_cmds_OverrideCmd$sub_nonrefs	_jc_ppg_cmds_OverrideCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_OverrideCmd$refs	_jc_ppg_cmds_OverrideCmd$refs;
typedef struct _jc_ppg_cmds_OverrideCmd$nonrefs	_jc_ppg_cmds_OverrideCmd$nonrefs;
typedef struct _jc_ppg_cmds_OverrideCmd$object	_jc_ppg_cmds_OverrideCmd$object;

typedef const struct _jc_ppg_cmds_OverrideCmd$vmethods	_jc_ppg_cmds_OverrideCmd$vmethods;
typedef const struct _jc_ppg_cmds_OverrideCmd$vtable	_jc_ppg_cmds_OverrideCmd$vtable;
typedef const struct _jc_ppg_cmds_OverrideCmd$vtype	_jc_ppg_cmds_OverrideCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_OverrideCmd$method$_init$366f936045042a22(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *, struct _jc_ppg_atoms_Production$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_ppg_atoms_Nonterminal$object *_jc_ppg_cmds_OverrideCmd$method$getLHS$7fbea68fdd3a7c01(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *) _JC_JCNI_ATTR;
extern struct _jc_ppg_atoms_Production$object *_jc_ppg_cmds_OverrideCmd$method$getProduction$794612980e712f24(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_cmds_OverrideCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_OverrideCmd$method_info$getLHS$7fbea68fdd3a7c01;
extern _jc_method _jc_ppg_cmds_OverrideCmd$method_info$getProduction$794612980e712f24;
extern _jc_method _jc_ppg_cmds_OverrideCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_OverrideCmd$vmethods {
	struct _jc_ppg_atoms_Nonterminal$object	*(*getLHS$7fbea68fdd3a7c01)(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *) _JC_JCNI_ATTR;
	struct _jc_ppg_atoms_Production$object	*(*getProduction$794612980e712f24)(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_OverrideCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_cmds_OverrideCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_OverrideCmd$vmethods	ppg_cmds_OverrideCmd;
};

// Vtype
struct _jc_ppg_cmds_OverrideCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_OverrideCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_OverrideCmd$sub_refs {
	struct _jc_ppg_atoms_Production$object	*prod;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_OverrideCmd$refs {
    _jc_ppg_cmds_OverrideCmd$sub_refs	ppg_cmds_OverrideCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_OverrideCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_OverrideCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_OverrideCmd$sub_nonrefs	ppg_cmds_OverrideCmd;
};

// Object instance structure
struct _jc_ppg_cmds_OverrideCmd$object {
	_jc_ppg_cmds_OverrideCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_OverrideCmd$vtype	*vtype;
	_jc_ppg_cmds_OverrideCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_OverrideCmd$vtype _jc_ppg_cmds_OverrideCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_OverrideCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_OverrideCmd$class_object;

#endif	/* _JC_ppg_cmds_OverrideCmd_H_ */
